S3Config class

Constructors

S3Config({required String bucket, required String region, required String accessKey, required String secretKey, String? sessionToken})
const
S3Config.fromEnvironment(Map<String, String> env)
factory

Properties

accessKey String
final
bucket String
final
hashCode int
The hash code for this object.
no setterinherited
region String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String
final
sessionToken String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited