FileStorage class
- Inheritance
-
- Object
- PackageStorage
- FileStorage
Constructors
- FileStorage({required String baseDir, String customFilePath(String name, String version)?})
Properties
- baseDir ↔ String
-
getter/setter pair
- customFilePath ↔ String Function(String name, String version)?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportDownloadUrl → bool
-
no setteroverride
Methods
-
download(
String name, String version) → Stream< List< int> > -
override
-
downloadUrl(
String name, String version) → FutureOr< String> -
inherited
-
getPackagePath(
{required String name, required String version}) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
upload(
String name, String version, List< int> content) → Future<String> -
return sha256 hash of the file
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited