PackageStorage class abstract

Implementers

Constructors

PackageStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportDownloadUrl bool
no setter

Methods

download(String name, String version) Stream<List<int>>
downloadUrl(String name, String version) FutureOr<String>
getPackagePath({required String name, required String version}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload(String name, String version, List<int> content) Future<String>
return sha256 hash of the file

Operators

operator ==(Object other) bool
The equality operator.
inherited