S3Storage class

Inheritance

Constructors

S3Storage({required Minio minio, required String bucket, String prefix = 'packages'})
S3Storage.fromConfig(S3Config config, {String prefix = 'packages'})
factory

Properties

bucket String
final
hashCode int
The hash code for this object.
no setterinherited
prefix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportDownloadUrl bool
no setteroverride

Methods

download(String name, String version) Stream<List<int>>
override
downloadUrl(String name, String version) FutureOr<String>
override
getPackagePath({required String name, required String version}) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload(String name, String version, List<int> content) Future<String>
return sha256 hash of the file
override

Operators

operator ==(Object other) bool
The equality operator.
inherited