UserAccount class

Constructors

UserAccount({required String username, required String email, required String passwordHash, required List<String> tokenHashes, required DateTime createdAt, required DateTime updatedAt, required String bio, required List<String> likedPackages, required List<UserActivity> activities, String? currentToken})
UserAccount.fromJson(Map<String, dynamic> json)
factory

Properties

activities List<UserActivity>
final
bio String
final
createdAt DateTime
final
currentToken String?
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
likedPackages List<String>
final
passwordHash String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
no setter
tokenHashes List<String>
final
updatedAt DateTime
final
username String
final

Methods

copyWith({String? username, String? bio, List<String>? tokenHashes, List<String>? likedPackages, List<UserActivity>? activities, DateTime? updatedAt, String? currentToken}) UserAccount
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toPublicJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
withToken(String token) UserAccount

Operators

operator ==(Object other) bool
The equality operator.
inherited