UserStore class

Constructors

UserStore({required String baseDir})

Properties

baseDir String
final
filePath String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addActivity({required String email, required String action, required String message}) Future<void>
addLike({required String email, required String packageName}) Future<UserAccount>
findByToken(String token) Future<UserAccount?>
init() Future<void>
login({required String username, required String email, required String password}) Future<UserAccount>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register({required String username, required String email, required String password}) Future<UserAccount>
removeLike({required String email, required String packageName}) Future<UserAccount>
toString() String
A string representation of this object.
inherited
updateProfile({required String email, String? username, String? bio}) Future<UserAccount>

Operators

operator ==(Object other) bool
The equality operator.
inherited