BackendConfig class
Constructors
- BackendConfig({required MetaBackend metaBackend, required PackageBackend packageBackend, S3Config? s3})
-
const
-
BackendConfig.fromSources({Map<
String, String> ? env}) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- metaBackend → MetaBackend
-
final
- packageBackend → PackageBackend
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s3 → S3Config?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultMetaBackend → const String
- defaultPackageBackend → const String