SqliteMetaStorage class
[
{
'name': string,
'private': boolean,
'uploaders': string,
'download': number,
'createdAt': string,
'updatedAt': string,
'versions':
{
'version': string,
'pubspect': {},
'pubspecYaml': string,
'uploader': string,
'readme': string,
'changelog': string,
'createdAt': string,
}
}
]
- Inheritance
-
- Object
- PackageRepository
- SqliteMetaStorage
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
active(
{String? baseDir}) → FutureOr -
override
-
addRecord(
String name, PackageVersion version) → FutureOr -
override
-
addUploader(
String name, String email) → FutureOr -
override
-
deactive(
) → FutureOr -
override
-
increaseDownloads(
String name, String version) → FutureOr -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queries(
{required int size, required int page, required String sort, required String keyword, String? uploader, String? dependency}) → Future< List< UnpuberPackage> > -
override
-
query(
String name, {String? version}) → Future< UnpuberPackage?> -
override
-
removeUploader(
String name, String email) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
upsertRecord(
String name, Map< String, dynamic> data) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited